<?php

/**
 * @file
 * The system user manager class.
 *
 * Used to identify and retrieve system users.
 */

/**
 * A class for retrieving system users.
 */
class SystemUserManager {

  /**
   * The name of the base field.
   */
  const FIELD_NAME = 'system_user';

  /**
   * Return all system users.
   *
   * @return \stdClass[]
   *   An array of system users.
   */
  public function getAll() {
    return user_load_multiple(
      $this->query()->execute()->fetchCol()
    );
  }

  /**
   * Return the first system user.
   *
   * @return \stdClass|FALSE
   *   The first system user, or FALSE if one was not found.
   */
  public function getFirst() {
    $uid = $this->query()
      ->range(0, 1)
      ->execute()
      ->fetchField();

    return user_load($uid);
  }

  /**
   * Return a count of the total number of system users.
   *
   * @return int
   *   The number of system users.
   */
  public function getCount() {
    return $this->query()->execute()->rowCount();
  }

  /**
   * Generate the base query.
   *
   * @return SelectQuery
   *   The base query.
   */
  private function query() {
    return db_select('users', 'u')
      ->fields('u', ['uid'])
      ->condition(self::FIELD_NAME, 1);
  }

  /**
   * Determine if a user is a system user.
   *
   * @param \stdClass $user
   *   The user to check.
   *
   * @return bool
   *   TRUE or FALSE.
   */
  public static function isSystemUser(\stdClass $user) {
    return $user->{static::FIELD_NAME} == 1;
  }

}
